@@ -8,6 +8,7 @@
 from __future__ import unicode_literals
 import re
 from ural.patterns import URL_IN_HTML_RE
+from ural.utils import urljoin
 
 
 def clean_link(link):
@@ -15,17 +16,23 @@ def clean_link(link):
     return link.strip("\t\r\n '\"\x0c")
 
 
-def urls_from_html(string):
+def urls_from_html(string, base_url=None):
     """
     Function returning an iterator over the urls present in the HTML string argument.
 
     Args:
         string (str): source html string.
+        base_url (str, optional): base_url to concatenate to the found urls.
+            Defaults to None.
 
     Yields:
         str: an url.
 
     """
-    for a_tag in re.finditer(URL_IN_HTML_RE, string):
-        url = a_tag.group(3)
-        yield clean_link(url)
+    for match in re.finditer(URL_IN_HTML_RE, string):
+        url = clean_link(match.group(1))
+
+        if base_url is not None:
+            url = urljoin(base_url, url)
+
+        yield url
